package com.rshka.mcs.controllers;

import java.util.List;
import java.util.logging.ErrorManager;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.rshka.mcs.beans.Customer;
import com.rshka.mcs.beans.ErrorMcs;
import com.rshka.mcs.beans.GetCustomerRespData;
import com.rshka.mcs.beans.GetCustomersRespData;
import com.rshka.mcs.beans.PostCustomerData;
import com.rshka.mcs.service.CustomerService;

@RestController
@RequestMapping(value = "/customer")
public class CustomerController {

	@Autowired
	private CustomerService customerService;

	@RequestMapping(value = "/{document}", produces = MediaType.APPLICATION_JSON_VALUE)
	public ResponseEntity getCustomer(@PathVariable(value = "document") String document) {

		try {

			Customer customer = customerService.getCustomer(document);

			return new ResponseEntity<GetCustomerRespData>(new GetCustomerRespData(customer), HttpStatus.OK);

		} catch (Exception e) {
			e.printStackTrace();
			return new ResponseEntity<ErrorMcs>(new ErrorMcs("FTL_PF_1000", e.getMessage()),
					HttpStatus.UNPROCESSABLE_ENTITY);
		}
	}

	@RequestMapping(value = "/list", produces = MediaType.APPLICATION_JSON_VALUE)
	public ResponseEntity getCustomerList() {

		try {

			List<Customer> customer = customerService.getCustomers();

			return new ResponseEntity<GetCustomersRespData>(new GetCustomersRespData(customer), HttpStatus.OK);

		} catch (Exception e) {
			e.printStackTrace();
			return new ResponseEntity<ErrorMcs>(new ErrorMcs("FTL_PF_1000", e.getMessage()),
					HttpStatus.UNPROCESSABLE_ENTITY);
		}
	}

	@RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE)
	public ResponseEntity save(@RequestBody Customer customer) {

		try {

			Integer id = customerService.saveCustomer(customer);

			return new ResponseEntity<PostCustomerData>(new PostCustomerData(id), HttpStatus.OK);

		} catch (Exception e) {
			e.printStackTrace();
			return new ResponseEntity<ErrorMcs>(new ErrorMcs("FTL_PF_1000", e.getMessage()),
					HttpStatus.UNPROCESSABLE_ENTITY);
		}
	}

}
